@@ -8,6 +8,7 @@ use Elive::Entity;
 use base qw{ Elive::Entity };
 
 __PACKAGE__->entity_name('MeetingParameters');
+__PACKAGE__->isa('Meeting');
 
 has 'meetingId' => (is => 'rw', isa => 'Int', required => 1,
     documentation => 'associated meeting');
@@ -61,14 +62,14 @@ This class contains additional meeting information.
 
 =cut
 
-=head2 create
+=head2 insert
 
-The create method is not applicable. The meeting parameters table is
+The insert method is not applicable. The meeting parameters table is
 automatically created when you create a table.
 
 =cut
 
-sub create {shift->_not_available}
+sub insert {shift->_not_available}
 
 =head2 delete
 
